import {
  APIRequest,
  MessageAPIResponse,
  APIDecoder,
  APIJsonEncoder
} from '@ucap-webmessenger/api';
import { DeviceType } from '@ucap-webmessenger/core';
import { MessageType } from '../types/message.type';
import { MessageList } from '../models/message-list';

export interface RetrieveRequest extends APIRequest {
  userSeq: number;
  deviceType: DeviceType;
  tokenKey: string;
  type: MessageType;
  pageSize: number;
  pageCount: number;
}
export interface RetrieveSearchRequest extends RetrieveRequest {
  searchTitle: string;
  searchName: string;
  searchContent: string;
}

export interface RetrieveResponse extends MessageAPIResponse {
  totalCount: number;

  messageList: MessageList[];
}

export const encodeRetrieve: APIJsonEncoder<RetrieveRequest> = (
  req: RetrieveRequest
) => {
  return JSON.stringify(req);
};
export const encodeRetrieveSearch: APIJsonEncoder<RetrieveResponse> = (
  req: RetrieveResponse
) => {
  return JSON.stringify(req);
};

export const decodeRetrieveSend: APIDecoder<RetrieveResponse> = (res: any) => {
  return {
    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveReceive: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveReservation: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};

export const decodeRetrieveSearch: APIDecoder<RetrieveResponse> = (
  res: any
) => {
  return {
    responseCode: res.responseCode,
    responseMsg: res.responseMsg,
    totalCount: res.totalCount,
    messageList: []
  } as RetrieveResponse;
};
